@@ -15,7 +15,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
+ *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.           *
  ***************************************************************************/
 
 #include "config.h"
@@ -29,6 +29,7 @@
 #include <math.h>
 
 #include "notebook.h"
+#include "internal.h"
 	
 #define GTK_FILL_EXPAND (GtkAttachOptions)(GTK_FILL|GTK_EXPAND)
 
@@ -401,11 +402,11 @@ static void createControl(GtkWidget *parent,struct control_db *control)
 				
 				gtk_range_set_increments(GTK_RANGE(widget),
 						100.0/(double)currentMaximum,
-						10.0*100.0/(double)currentMaximum);
+						100.0/(double)currentMaximum);
 				gtk_range_set_value(GTK_RANGE(widget),
 						(double)100.0*currentDefault/(double)currentMaximum);
 						
-				g_signal_connect_after(G_OBJECT(widget), "value-changed", G_CALLBACK(range_callback), NULL);
+				g_signal_connect_after(G_OBJECT(widget), "change-value", G_CALLBACK(range_callback), NULL);
 			}
 			break;
 		case command:
@@ -588,7 +589,7 @@ void create_monitor_manager(struct monitorlist* monitor)
 	
 	if (ddcci_open(mon, monitor->filename, 0) < 0) {
 		set_message(_(
-			"An error occured while opening the monitor device.\n"
+			"An error occurred while opening the monitor device.\n"
 			"Maybe this monitor was disconnected, please click on "
 			"the refresh button near the monitor list."));
 		monitor_manager = NULL;
