@@ -15,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 */
 
 #include <errno.h>
@@ -30,6 +30,7 @@
 
 #include "monitor_db.h"
 #include "ddcci.h"
+#include "internal.h"
 
 /* Localize, and alloc in libxml */
 #ifdef HAVE_GETTEXT
